@@ -1,7 +1,6 @@
 import os
 from operator import attrgetter
 from typing import List, TextIO, Dict, AnyStr, Sequence, Tuple, Union
-import logging
 
 import numpy as np
 import pickle
@@ -193,12 +192,10 @@ class Simulation:
         """Load information for a single mesh from the smv file at current pointer position.
         """
         mesh_id = line.split()[1]
-        logging.debug("Found MESH with id: %s", mesh_id)
 
         grid_numbers = smv_file.readline().strip().split()
         grid_dimensions = {'x': int(grid_numbers[0]) + 1, 'y': int(grid_numbers[1]) + 1,
                            'z': int(grid_numbers[2]) + 1}
-        logging.debug("Number of cells: %i x %i x %i", *grid_dimensions.values())
 
         smv_file.readline()  # Blank line
         assert smv_file.readline().strip() == "PDIM"
@@ -453,6 +450,7 @@ class Simulation:
         mesh_index = int(line.split('&')[0].strip().split()[1]) - 1
         mesh = self.meshes[mesh_index]
 
+        # print("slcf:")
         # Read in index ranges for x, y and z
         bound_indices = [int(i.strip()) for i in line.split('&')[1].split('!')[0].strip().split()]
         extent, dimension = self._indices_to_extent(bound_indices, mesh)
@@ -480,8 +478,6 @@ class Simulation:
             {"dimension": dimension, "extent": extent, "mesh": mesh, "filename": filename,
              "quantity": quantity, "label": label, "unit": unit})
 
-        logging.debug("Found SLICE with id: :i", slice_index)
-
     @log_error("bndf")
     def _load_boundary_data(self, smv_file: TextIO, line: str, cell_centered: bool):
         """Loads the boundary data at current pointer position.
@@ -501,19 +497,25 @@ class Simulation:
 
         patches = dict()
 
-        times = list()
-        lower_bounds = list()
-        upper_bounds = list()
-        with open(file_path + ".bnd", 'r') as bnd_file:
-            for line in bnd_file:
-                splits = line.split()
-                times.append(float(splits[0]))
-                lower_bounds.append(float(splits[1]))
-                upper_bounds.append(float(splits[2]))
-        times = np.array(times)
-        lower_bounds = np.array(lower_bounds, dtype=np.float32)
-        upper_bounds = np.array(upper_bounds, dtype=np.float32)
-        n_t = times.shape[0]
+        if os.path.exists(file_path + ".bnd"):
+            times = list()
+            lower_bounds = list()
+            upper_bounds = list()
+            with open(file_path + ".bnd", 'r') as bnd_file:
+                for line in bnd_file:
+                    splits = line.split()
+                    times.append(float(splits[0]))
+                    lower_bounds.append(float(splits[1]))
+                    upper_bounds.append(float(splits[2]))
+            times = np.array(times)
+            lower_bounds = np.array(lower_bounds, dtype=np.float32)
+            upper_bounds = np.array(upper_bounds, dtype=np.float32)
+            n_t = times.shape[0]
+        else:
+            times = None
+            n_t = -1
+            lower_bounds = np.array([0.0], dtype=np.float32)
+            upper_bounds = np.array([np.float32(-1e33)], dtype=np.float32)
 
         with open(file_path, 'rb') as infile:
             # Offset of the binary file to the end of the file header.
@@ -526,15 +528,17 @@ class Simulation:
             patch_infos = fdtype.read(infile, dtype_patches, n_patches)
             offset += fdtype.INT.itemsize + dtype_patches.itemsize * n_patches
             patch_offset = fdtype.FLOAT.itemsize
-            # cell_centered = False
+
             for patch_info in patch_infos:
                 patch_info = patch_info[0]
+
+                # print("bndf:")
                 extent, dimension = self._indices_to_extent(patch_info[:6], mesh)
                 orientation = patch_info[6]
                 obst_index = patch_info[7]
 
                 p = Patch(file_path, dimension, extent, orientation, cell_centered,
-                          patch_offset + offset, n_t)
+                          patch_offset, offset, n_t)
 
                 # Skip obstacles with index 0, which just gives the extent of the (whole) mesh faces
                 # These might be needed in case of "closed" mesh faces
@@ -796,6 +800,7 @@ class Simulation:
         x_min, x_max, y_min, y_max, z_min, z_max = (
             int(indices[0]), int(indices[1]), int(indices[2]), int(indices[3]), int(indices[4]),
             int(indices[5]))
+        # if x_min != x_max: print(x_min, x_max)
         co_x_min, co_x_max, co_y_min, co_y_max, co_z_min, co_z_max = (
             co['x'][x_min], co['x'][x_max], co['y'][y_min],
             co['y'][y_max], co['z'][z_min], co['z'][z_max])
